/*
 * This file belongs to the XQuark distribution.
 * Copyright (C) 2003 Universite de Versailles Saint-Quentin.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquark.org.
 */

/**
 * Created on 15 nov. 2002
 *
 * To change this generated comment edit the template variable "filecomment":
 * Window>Preferences>Java>Templates.
 * To enable and disable the creation of file comments go to
 * Window>Preferences>Java>Code Generation.
 */
package org.xquark.repository.dbms;

/**
 * Object containing DBMS specific information
 *
 */
public class DBMSInfo
{
	private static final String RCSRevision = "$Revision: 1.3 $";
	private static final String RCSName = "$Name:  $";

    private short dbms;
	private int systemCollectionsDataLength = 255;
    private int maxUserCollectionsDataLength = 255;	// indexable size
    private String rowId = null;
	private boolean namesConvertedToUppercase = false;
	private boolean useDoubleQuotes4DDLNames = false;
	private SQLStatementCustomizer selectLockStatement = null;
	private SQLStatementCustomizer temporaryTableStatement = null;
	private SQLStatementCustomizer indexOrganizedStatement = null;
    private TypeMap typeMap = null;

	/**
	 * Returns the typeMap.
	 * @return TypeMap
	 */
	public TypeMap getTypeMap()
	{
		return typeMap;
	}

	/**
	 * Returns the dbms.
	 * @return short
	 */
	public short getDbms()
	{
		return dbms;
	}

	/**
	 * Returns the selectLockStatement.
	 * @return String
	 */
	public SQLStatementCustomizer getSelectLockStatement()
	{
		return selectLockStatement;
	}

	/**
	 * Returns the maxUserCollectionsDataLength.
	 * @return int
	 */
	public int getMaxUserCollectionsDataLength()
	{
		return maxUserCollectionsDataLength;
	}

	/**
	 * Returns the namesConvertedToUppercase.
	 * @return boolean
	 */
	public boolean isNamesConvertedToUppercase()
	{
		return namesConvertedToUppercase;
	}

	/**
	 * Returns the useDoubleQuotesForDatabaseObjects.
	 * @return boolean
	 */
	public boolean useDoubleQuotes4DDLNames()
	{
		return useDoubleQuotes4DDLNames;
	}

	/**
	 * Returns the rowId.
	 * @return String
	 */
	public String getRowId()
	{
		return rowId;
	}

	/**
	 * Returns the systemCollectionsDataLength.
	 * @return int
	 */
	public int getSystemCollectionsDataLength()
	{
		return systemCollectionsDataLength;
	}

	/**
	 * Sets the typeMap.
	 * @param typeMap The typeMap to set
	 */
	public void setTypeMap(TypeMap typeMap)
	{
		this.typeMap = typeMap;
	}

	/**
	 * Sets the dbms.
	 * @param dbms The dbms to set
	 */
	public void setDbms(short dbms)
	{
		this.dbms = dbms;
	}

	/**
	 * Sets the selectLockStatement.
	 * @param selectLockStatement The selectLockStatement to set
	 */
	public void setSelectLockStatement(SQLStatementCustomizer selectLockStatement)
	{
		this.selectLockStatement = selectLockStatement;
	}

	/**
	 * Sets the maxUserCollectionsDataLength.
	 * @param maxUserCollectionsDataLength The maxUserCollectionsDataLength to set
	 */
	public void setMaxUserCollectionsDataLength(int maxUserCollectionsDataLength)
	{
		this.maxUserCollectionsDataLength = maxUserCollectionsDataLength;
	}

	/**
	 * Sets the namesConvertedToUppercase.
	 * @param namesConvertedToUppercase The namesConvertedToUppercase to set
	 */
	public void setNamesConvertedToUppercase(boolean namesConvertedToUppercase)
	{
		this.namesConvertedToUppercase = namesConvertedToUppercase;
	}

	/**
	 * Sets the useDoubleQuotesForDatabaseObjects.
	 * @param useDoubleQuotesForDatabaseObjects The useDoubleQuotesForDatabaseObjects to set
	 */
	public void setUseDoubleQuotes4DDLNames(boolean useDoubleQuotesForDatabaseObjects)
	{
		this.useDoubleQuotes4DDLNames = useDoubleQuotesForDatabaseObjects;
	}

	/**
	 * Sets the rowId.
	 * @param rowId The rowId to set
	 */
	public void setRowId(String rowId)
	{
		this.rowId = rowId;
	}

	/**
	 * Sets the systemCollectionsDataLength.
	 * @param systemCollectionsDataLength The systemCollectionsDataLength to set
	 */
	public void setSystemCollectionsDataLength(int systemCollectionsDataLength)
	{
		this.systemCollectionsDataLength = systemCollectionsDataLength;
	}

	/**
	 * Returns the indexOrganizedStatement.
	 * @return SQLStatementCustomizer
	 */
	public SQLStatementCustomizer getIndexOrganizedStatement()
	{
		return indexOrganizedStatement;
	}

	/**
	 * Returns the temporaryTableStatement.
	 * @return SQLStatementCustomizer
	 */
	public SQLStatementCustomizer getTemporaryTableStatement()
	{
		return temporaryTableStatement;
	}

	/**
	 * Sets the indexOrganizedStatement.
	 * @param indexOrganizedStatement The indexOrganizedStatement to set
	 */
	public void setIndexOrganizedStatement(SQLStatementCustomizer indexOrganizedHint)
	{
		this.indexOrganizedStatement = indexOrganizedHint;
	}

	/**
	 * Sets the temporaryTableStatement.
	 * @param temporaryTableStatement The temporaryTableStatement to set
	 */
	public void setTemporaryTableStatement(SQLStatementCustomizer temporaryTableHint)
	{
		this.temporaryTableStatement = temporaryTableHint;
	}

}
