/*
 * This file belongs to the XQuark distribution.
 * Copyright (C) 2003 Universite de Versailles Saint-Quentin.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquark.org.
 */

package org.xquark.repository.dbms;

import org.xquark.util.AttributeTracker;
import org.xquark.util.SaxMapper;
import org.xquark.util.TagTracker;

/**
 *
 */
public class DBMSInfoLoader extends SaxMapper
{
    private static final String RCSRevision = "$Revision: 1.3 $"; 
    private static final String RCSName     = "$Name:  $";

    
    private DBMSInfo dbmsInfo;
	private TypeMap.TargetNativeType wType;
	private SQLStatementCustomizer wStmtCustomizer;
	private String wClause;
    
	/**
	 * @see org.xquark.xml.util.SaxMapper#createTagTrackerNetwork()
	 */
	public TagTracker createTagTrackerNetwork()
	{
		// create root
		TagTracker root = new TagTracker() {
			public void onDeactivate()
			{
				dbmsInfo = new DBMSInfo();
				dbmsInfo.setTypeMap(new TypeMap());
			}
		};
		
		// create action for /dbmsInfo/limits/systemCollectionsDataLength
		root.track
			(
			"/dbmsInfo/limits/systemCollectionsDataLength",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					dbmsInfo.setSystemCollectionsDataLength(((Number)actualValue).intValue());
				}
			}
			);
		
		// create action for /dbmsInfo/limits/userCollectionMaxDataLength
		root.track
			(
			"/dbmsInfo/limits/userCollectionMaxDataLength",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					dbmsInfo.setMaxUserCollectionsDataLength(((Number)actualValue).intValue());
				}
			}
			);
		
		// create action for /dbmsInfo/SQLTokens/lockHint
		TagTracker lockHint = new TagTracker() {
			public void onEnd(
					String namespaceURI,
					String localName,
					Object actualValue)
			{
				dbmsInfo.setSelectLockStatement(new SQLStatementCustomizer((String)actualValue));
			}
		};
		root.track("/dbmsInfo/SQLTokens/selectLockStatement", lockHint);
		
		// create action for /dbmsInfo/SQLTokens/temporaryTableSpecification
		TagTracker tmpTableHint = new TagTracker() {
			public void onEnd(
					String namespaceURI,
					String localName,
					Object actualValue)
			{
				dbmsInfo.setTemporaryTableStatement(new SQLStatementCustomizer((String)actualValue));
			}
		};
		root.track("/dbmsInfo/SQLTokens/temporaryTableSpecification", tmpTableHint);

		// create action for /dbmsInfo/SQLTokens/indexOrganizationSpecification
		TagTracker indexOrgHint = new TagTracker() {
			public void onEnd(
					String namespaceURI,
					String localName,
					Object actualValue)
			{
				dbmsInfo.setIndexOrganizedStatement(new SQLStatementCustomizer((String)actualValue));
			}
		};
		root.track("/dbmsInfo/SQLTokens/indexOrganizationSpecification", indexOrgHint);

		// create action for /dbmsInfo/SQLTokens/rowID
		root.track
			(
			"/dbmsInfo/SQLTokens/rowID",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					dbmsInfo.setRowId((String)actualValue);
				}
			}
			);
		
		// create action for /dbmsInfo/SQLTokens/DDLNamesConvertedToUpperCase
		root.track
			(
			"/dbmsInfo/SQLTokens/DDLNamesConvertedToUpperCase",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					dbmsInfo.setNamesConvertedToUppercase(((Boolean)actualValue).booleanValue());
				}
			}
			);
		
		// create action for /dbmsInfo/SQLTokens/useDoubleQuotesToPreserveDDLNamesCase
		root.track
			(
			"/dbmsInfo/SQLTokens/useDoubleQuotesToPreserveDDLNamesCase",
			new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					dbmsInfo.setUseDoubleQuotes4DDLNames(((Boolean)actualValue).booleanValue());
				}
			}
			);
		
		// create action for /dbmsInfo/typeMapping/type
		TagTracker type = new TagTracker() {
			public void onStart(
						String namespaceURI,
						String localName)
			{
				wType = new TypeMap.TargetNativeType();
			}
			public void onReactivate()
			{
				dbmsInfo.getTypeMap().addType(wType);
			}
		};
		root.track("/dbmsInfo/typeMapping/type", type);
		
		// create action for /dbmsInfo/typeMapping/type/@jdbcType
		type.trackAttribute(
			"@jdbcType",
		 	new AttributeTracker() {
				public void onAttributeEncountered
					(
					String namespaceURI,
					String localName,
					Object actualValue
					)
				{
					wType.setJDBCType((String)actualValue);
				}
			}
			);
		
		// create action for /dbmsInfo/typeMapping/type/nativeName
		type.track(
			"nativeName",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					wType.setNativeTypeName((String)actualValue);
				}
			}
			);
		
		// create action for /dbmsInfo/typeMapping/type/size
		type.track(
			"size",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					wType.setPrecision(((Number)actualValue).longValue());
				}
			}
			);
		
		// create action for /dbmsInfo/typeMapping/type/precision
		type.track(
			"precision",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					wType.setPrecision(((Number)actualValue).longValue());
				}
			}
			);
		
		// create action for /dbmsInfo/typeMapping/type/unsigned
		type.track(
			"unsigned",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					wType.setUnsigned(((Boolean)actualValue).booleanValue());
				}
			}
			);
		
		// create action for /dbmsInfo/typeMapping/type/fixedCreateParams
		type.track(
			"fixedCreateParams",
		 	new TagTracker() {
				public void onEnd(
						String namespaceURI,
						String localName,
						Object actualValue)
				{
					wType.setTypeParam((String)actualValue);
				}
			}
			);
		
		return root;
	}

	/**
	 * @see org.xquark.xml.util.SaxMapper#getMappedObject()
	 */
	public Object getMappedObject()
	{
		return dbmsInfo;
	}
}
