/*
 * This file belongs to the XQuark distribution.
 * Copyright (C) 2003 XQuark Group.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquark.org.
 */

package org.xquark.repository.mapping.mysql;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.xquark.repository.dbms.TypeMap;
import org.xquark.repository.mapping.ColumnMetaDataImpl;

/**
 * This class maintains the meta information about a column in a relational
 * table. This information is useful to verify the integrity constraints
 * in the the relational tables.
 *
 * This class is the specific implementation for MySQL fixing some particular
 * behavior.
 */
public class MySQLColumnMetaData extends ColumnMetaDataImpl
{
private static final String RCSRevision = "$Revision: 1.1 $"; 
private static final String RCSName     = "$Name:  $";

    /**
     * Constructor.
     *
     * The constructor of the ColumnMetaData is only called by the
     * TableMetaData class in its contructor.
     */
    public MySQLColumnMetaData(ResultSet rs, TypeMap typeMap) throws SQLException
    {
    	super(rs, typeMap);
		if (columnDef != null && columnDef.length() == 0)
			columnDef = null;
		// NOTE: MySQL Connector 3.0.9 returns "" when there is no default value...
    }
}
