/*
 * This file belongs to the XQuark distribution.
 * Copyright (C) 2003 Universite de Versailles Saint-Quentin.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquark.org.
 */

package org.xquark.repository.mapping.oracle;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;

import org.xquark.repository.mapping.ColumnMetaDataImpl;

/**
 * This class maintains the meta information about a column in a relational
 * table. This information is useful to verify the integrity constraints
 * in the the relational tables.
 *
 * This class is the default JDBC implementation of ColumnMetaData
 */
public class O8iColumnMetaData extends ColumnMetaDataImpl
{
private static final String RCSRevision = "$Revision: 1.2 $"; 
private static final String RCSName     = "$Name:  $";

    /**
     * Constructor.
     *
     * The constructor of the ColumnMetaData is only called by the
     * TableMetaData class in its contructor.
     */
    public O8iColumnMetaData(ResultSet rs) throws SQLException
    {
        tableName = rs.getString(1);
        columnName = rs.getString(2);
        
        // 'primitive' JDBC type setting
        nativeType = rs.getString(3);
        columnSize = rs.getInt(4);
        if (rs.wasNull())
            columnSize = -1;
        int precision =  rs.getInt(5);
        if (rs.wasNull())
            precision = -1;
        decimalDigits = rs.getInt(6);
        if (rs.wasNull())
            decimalDigits = -1;
        
        
        // type creation string
        typeDDLString = nativeType;
        
        // base abstract JDBC type setting
        if (nativeType.equals("VARCHAR2")
            || nativeType.equals("NVARCHAR2")
            || nativeType.equals("NCHAR")        
            || nativeType.equals("CHAR"))
        {
            JDBCtype = Types.VARCHAR;
            if (columnSize >= 0)
                typeDDLString += "(" + columnSize + ")";
        }
        else if (nativeType.equals("CLOB"))
        {
            JDBCtype = Types.VARCHAR;
            columnSize = 0x100000000L;
            isLOB = true;
            isLongType = true;
        }
        else if (nativeType.equals("LONG"))
        {
            JDBCtype = Types.VARCHAR;
            columnSize = 0xFFFFFFFFL;
            isLongType = true;
        }
        else if (nativeType.equals("FLOAT"))
        {
            if (precision == 126)
                JDBCtype = Types.DOUBLE;
            else    // TO IMPROVE : not correct if < 63...
                JDBCtype = Types.REAL;
            if (precision >= 0)
                typeDDLString += "(" + precision + ")";
       }
        else if (nativeType.equals("NUMBER"))
        {
            if ((precision == -1) && (decimalDigits == -1))
                JDBCtype = Types.DOUBLE;
            else
            {
                JDBCtype = Types.DECIMAL;
                if (precision == -1)
                    precision = 38;
                else
                {
                    typeDDLString += "(" + precision;
                    if (decimalDigits >= 0)
                        typeDDLString += "," + decimalDigits;
                    typeDDLString += ")";
                }
            }
        }
        else if (nativeType.equals("RAW"))
        {
            JDBCtype = Types.VARBINARY;
            if (columnSize >= 0)
                typeDDLString += "(" + columnSize + ")";
        }
        else if (nativeType.equals("LONG RAW"))
        {
            JDBCtype = Types.VARBINARY;
            columnSize = 0xFFFFFFFFL;
            isLongType = true;
        }
        else if (nativeType.equals("BLOB") || nativeType.equals("BFILE"))
        {
            JDBCtype = Types.VARBINARY;
            columnSize = 0x100000000L;
            isLOB = true;
            isLongType = true;
        }
        else if (nativeType.equals("DATE"))
            JDBCtype = Types.TIMESTAMP;


        nullable = !rs.getString(7).equals("N");
        ordinalPosition = rs.getInt(8);
        columnDef = rs.getString(9);
    }
}
