/*
 * This file belongs to the XQuark distribution.
 * Copyright (C) 2003 Universite de Versailles Saint-Quentin.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquark.org.
 */

package org.xquark.repository.storage;

import java.sql.PreparedStatement;
import java.sql.SQLException;

import org.xquark.repository.RepositoryException;
import org.xquark.repository.dbms.AbstractConnection;
import org.xquark.repository.mapping.ColumnMapping;
import org.xquark.repository.metadata.CollectionMappingInfo;
import org.xquark.repository.metadata.CollectionMetadata;
import org.xquark.repository.metadata.RepositoryConstants;
import org.xquark.repository.util.Debug;
import org.xquark.repository.util.RepositoryProperties;
import org.xquark.schema.Declaration;
import org.xquark.schema.validation.ValidationContextProvider;
import org.xquark.xml.xdbc.XMLDBCException;

class DocumentTuple extends Tuple
{
    
    private static final String RCSRevision = "$Revision: 1.4 $";
    
    private static final String RCSName = "$Name:  $";
    
    DocumentTuple(CollectionMappingInfo table)
    {
        super(table);
    }
    
    /** To be used by document reading  */
    void init(AbstractConnection connection, CollectionMetadata collection) throws SQLException, RepositoryException
    {
        try
        {
            selectStmt = connection.getConnection().prepareStatement(table.getSelectValuesStatement());
            Debug.print("Select value statement:", table.getSelectValuesStatement());
            connection.setFetchSize(selectStmt,
            RepositoryProperties.getIntProperty(RepositoryConstants.CONF_USER_FETCHSIZE));
        }
        catch (SQLException e)
        {
            selectStmt.close();
            throw e;
        }
    }
    
    /** To be used by document reading   */
    void execQuery(String ID) throws SQLException, RepositoryException
    {
        try
        {
            if (resultSet != null)
                resultSet.close();
            ((PreparedStatement)selectStmt).setString(1, ID);
            resultSet = ((PreparedStatement)selectStmt).executeQuery();
            notExhausted = true;
        }
        catch (SQLException e)
        {
            selectStmt.close();
            throw e;
        }
    }
    
    boolean fetchNextRow() throws SQLException
    {
        super.fetchNextRow();
        try
        {
            if (notExhausted)
            {
                notExhausted = resultSet.next();
                if (notExhausted)
                {
                    uoid = resultSet.getLong(getMapping().getUOIDIndex() + 1);   // num + resultset offset/ List
                    pathoid = resultSet.getShort(getMapping().getPathIDIndex() + 1);
                }
            }
            
            if (!notExhausted)
                reset();
            return notExhausted;
        }
        catch (SQLException e)
        {
            selectStmt.close();
            throw e;
        }
    }
    
    protected String fetchValue(ColumnMapping column, Declaration decl, ValidationContextProvider nsContext)
    throws SQLException, XMLDBCException
    {
        String ret = null;
        try
        {   // TEST BETWEEN getString et getObject
            if (notExhausted)
            {
                if (getMapping().isClustered())
                    ret = column.getTypeInfo().getParameter(resultSet,
                    column.getInsertColumnIndex() + 1,
                    decl,
                    nsContext);    // because first index starts at 0 and OID belongs to columns
                else
                    ret = column.getTypeInfo().getParameter(resultSet,
                    column.getInsertColumnIndex() + 3,
                    decl,
                    nsContext);   // because two first are XQuark index (UOID, pathOID) and index starts at 0
            }
        }
        catch (SQLException e)
        {
            selectStmt.close();
            throw e;
        }
        return ret;
    }
    
}

